# Crab Champions Save Manager

## Development Road Map
✅ - Finished  
⚙️ - In Progress  
❌ - Todo

- Main Menu ⚙️
- Settings Menu ❌
- Create a higher-level format, storing only minimal data from a save and creating a full save from said data ✅
- Backups System
  - Create a menu for storing backups from the current save ✅
  - Create a menu for loading stored backups to the current save ✅
  - Create a menu for editing backup data ⚙️
    - Find a way to watermark edited saves to prevent cheating ❌

For those interested in reading the code, the term "Neocrab" refers to the internal simplified save format.
